package users

import (
	"fmt"
	"os"
	"path"
	"sirlab.de/go/knyt/applicationConfig"
	"sirlab.de/go/knyt/user"
)

type Users struct {
	appConfig applicationConfig.ApplicationConfig
	users     map[string]*user.User
}

func NewUsers(appConfig applicationConfig.ApplicationConfig) Users {
	return Users{
		users:     make(map[string]*user.User),
		appConfig: appConfig,
	}
}

func (users Users) LoadUsers() error {
	dirName := path.Join(users.appConfig.DataDir, "users")
	files, err := os.ReadDir(dirName)
	if err != nil {
		return err
	}
	for _, file := range files {
		fileName := path.Join(dirName, file.Name())

		if usr, err := user.NewUserFromFile(fileName); err != nil {
			return err
		} else {
			users.AddUser(usr)
		}
	}

	return nil
}

func (users Users) AddUser(usr *user.User) {
	users.users[usr.Id] = usr
}

func (users Users) GetUserById(id string) (*user.User, error) {
	usr := users.users[id]
	if usr == nil {
		return nil, fmt.Errorf("unknown id")
	}
	return usr, nil
}
